--- asterisk-1.8.1/apps/app_followme.c	2010-09-02 05:20:59.000000000 +0000
+++ asterisk-1.8.1-patched/apps/app_followme.c	2010-12-15 19:16:50.000000000 +0000
@@ -162,7 +162,8 @@
 	FOLLOWMEFLAG_STATUSMSG = (1 << 0),
 	FOLLOWMEFLAG_RECORDNAME = (1 << 1),
 	FOLLOWMEFLAG_UNREACHABLEMSG = (1 << 2),
-	FOLLOWMEFLAG_DISABLEHOLDPROMPT = (1 << 3)
+	FOLLOWMEFLAG_DISABLEHOLDPROMPT = (1 << 3),
+	FOLLOWMEFLAG_NOANSWER = (1 << 4)
 };
 
 AST_APP_OPTIONS(followme_opts, {
@@ -170,6 +171,7 @@
 	AST_APP_OPTION('a', FOLLOWMEFLAG_RECORDNAME ),
 	AST_APP_OPTION('n', FOLLOWMEFLAG_UNREACHABLEMSG ),
 	AST_APP_OPTION('d', FOLLOWMEFLAG_DISABLEHOLDPROMPT ),
+	AST_APP_OPTION('N', FOLLOWMEFLAG_NOANSWER ),
 });
 
 static int ynlongest = 0;
@@ -1085,30 +1087,37 @@
 	}
 	ast_mutex_unlock(&f->lock);
 
-	/* Answer the call */
-	if (chan->_state != AST_STATE_UP) {
-		ast_answer(chan);
-	}
-
-	if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_STATUSMSG)) 
-		ast_stream_and_wait(chan, targs.statusprompt, "");
-
 	snprintf(namerecloc,sizeof(namerecloc),"%s/followme.%s",ast_config_AST_SPOOL_DIR,chan->uniqueid);
 	duration = 5;
 
-	if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_RECORDNAME)) 
-		if (ast_play_and_record(chan, "vm-rec-name", namerecloc, 5, "sln", &duration, ast_dsp_get_threshold_from_settings(THRESHOLD_SILENCE), 0, NULL) < 0)
-			goto outrun;
-
 	if (!ast_fileexists(namerecloc, NULL, chan->language))
 		ast_copy_string(namerecloc, "", sizeof(namerecloc));
-	if (!ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_DISABLEHOLDPROMPT)) {
-		if (ast_streamfile(chan, targs.plsholdprompt, chan->language))
-			goto outrun;
-		if (ast_waitstream(chan, "") < 0)
-			goto outrun;
+
+	if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_NOANSWER)) {
+		if (chan->_state != AST_STATE_UP) {
+			ast_indicate(chan, AST_CONTROL_RINGING);
+		}
+	} else {
+		/* Answer the call */
+		if (chan->_state != AST_STATE_UP) {
+			ast_answer(chan);
+		}
+
+		if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_STATUSMSG)) 
+			ast_stream_and_wait(chan, targs.statusprompt, "");
+
+		if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_RECORDNAME)) 
+			if (ast_play_and_record(chan, "vm-rec-name", namerecloc, 5, "sln", &duration, ast_dsp_get_threshold_from_settings(THRESHOLD_SILENCE), 0, NULL) < 0)
+				goto outrun;
+
+		if (!ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_DISABLEHOLDPROMPT)) {
+			if (ast_streamfile(chan, targs.plsholdprompt, chan->language))
+				goto outrun;
+			if (ast_waitstream(chan, "") < 0)
+				goto outrun;
+		}
+		ast_moh_start(chan, S_OR(targs.mohclass, NULL), NULL);
 	}
-	ast_moh_start(chan, S_OR(targs.mohclass, NULL), NULL);
 
 	targs.status = 0;
 	targs.chan = chan;
@@ -1122,8 +1131,11 @@
 	if (!ast_strlen_zero(namerecloc))
 		unlink(namerecloc);
 
+	if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_NOANSWER) && chan->_state != AST_STATE_UP) {
+		ast_answer(chan);
+	}
+
 	if (targs.status != 100) {
-		ast_moh_stop(chan);
 		if (ast_test_flag(&targs.followmeflags, FOLLOWMEFLAG_UNREACHABLEMSG)) 
 			ast_stream_and_wait(chan, targs.sorryprompt, "");
 		res = 0;
